<?php
/**
* The template for adding additional theme options in Customizer
*
* @package Catch Themes
* @subpackage Parallax Frame Pro
* @since Parallax Frame 1.0
*/

$wp_customize->add_panel( 'parallax_frame_theme_options', array(
    'description'    => esc_html__( 'Basic theme Options', 'parallax-frame-pro' ),
    'capability'     => 'edit_theme_options',
    'priority'       => 200,
    'title'    		 => esc_html__( 'Theme Options', 'parallax-frame-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'parallax_frame_breadcumb_options', array(
	'description'	=> esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'parallax-frame-pro' ),
	'panel'			=> 'parallax_frame_theme_options',
	'title'    		=> esc_html__( 'Breadcrumb Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[breadcumb_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[breadcumb_option]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_breadcumb_options',
	'settings' => 'parallax_frame_theme_options[breadcumb_option]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[breadcumb_on_homepage]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_on_homepage'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[breadcumb_on_homepage]', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_breadcumb_options',
	'settings' => 'parallax_frame_theme_options[breadcumb_on_homepage]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[breadcumb_seperator]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[breadcumb_seperator]', array(
	'input_attrs' => array(
    		'style' => 'width: 40px;'
		),
	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'parallax-frame-pro' ),
	'section' 	=> 'parallax_frame_breadcumb_options',
	'settings' 	=> 'parallax_frame_theme_options[breadcumb_seperator]',
	'type'     	=> 'text'
	)
);
	// Breadcrumb Option End

	// Comment Option
$wp_customize->add_section( 'parallax_frame_comment_option', array(
	'description'	=> esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'parallax-frame-pro' ),
	'panel' 		=> 'parallax_frame_theme_options',
	'title'   		=> esc_html__( 'Comment Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[comment_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );


$comment_option_types = parallax_frame_comment_options();
$choices = array();
foreach ( $comment_option_types as $comment_option_type ) {
	$choices[$comment_option_type['value']] = $comment_option_type['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[comment_option]', array(
		'choices'  	=> $choices,
		'label'		=> esc_html__( 'Comment Option', 'parallax-frame-pro' ),
		'section'   => 'parallax_frame_comment_option',
        'settings'  => 'parallax_frame_theme_options[comment_option]',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[disable_notes]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_notes'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[disable_notes]', array(
	'label'		=> esc_html__( 'Check to Disable Notes', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_comment_option',
    'settings'  => 'parallax_frame_theme_options[disable_notes]',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[disable_website_field]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[disable_website_field]', array(
	'label'		=> esc_html__( 'Check to Disable Website Field', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_comment_option',
    'settings'  => 'parallax_frame_theme_options[disable_website_field]',
	'type'		=> 'checkbox',
) );
	// Comment End

/**
 *  Remove Custom CSS option from WordPress 4.7 onwards
 *  //@remove Remove if block and custom_css when WordPress 5.0 is released
 */
if ( !function_exists( 'wp_update_custom_css_post' ) ) {
	// Custom CSS Option
	$wp_customize->add_section( 'parallax_frame_custom_css', array(
		'description'	=> esc_html__( 'Custom/Inline CSS', 'parallax-frame-pro'),
		'panel'  		=> 'parallax_frame_theme_options',
		'title'    		=> esc_html__( 'Custom CSS Options', 'parallax-frame-pro' ),
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'parallax_frame_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options[custom_css]', array(
			'label'		=> esc_html__( 'Enter Custom CSS', 'parallax-frame-pro' ),
			'section'   => 'parallax_frame_custom_css',
	        'settings'  => 'parallax_frame_theme_options[custom_css]',
			'type'		=> 'textarea',
	) );
	// Custom CSS End
}

	// Excerpt Options
$wp_customize->add_section( 'parallax_frame_excerpt_options', array(
	'panel'  	=> 'parallax_frame_theme_options',
	'title'    	=> esc_html__( 'Excerpt Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[excerpt_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[excerpt_length]', array(
	'description' => esc_html__( 'Excerpt length. Default is 40 words', 'parallax-frame-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => esc_html__( 'Excerpt Length (words)', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_excerpt_options',
	'settings' => 'parallax_frame_theme_options[excerpt_length]',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[excerpt_more_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[excerpt_more_text]', array(
	'label'    => esc_html__( 'Read More Text', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_excerpt_options',
	'settings' => 'parallax_frame_theme_options[excerpt_more_text]',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'parallax_frame_feed_redirect', array(
	'panel'			=> 'parallax_frame_theme_options',
	'description'	=> esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'parallax-frame-pro' ),
	'title'    		=> esc_html__( 'Feed Redirect', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[feed_redirect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[feed_redirect]', array(
	'label'    => esc_html__( 'Feed Redirect', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_feed_redirect',
	'settings' => 'parallax_frame_theme_options[feed_redirect]',
	'type'	   => 'text',
) );
// Feed Redirect End

// Fixed Header Top Options
$wp_customize->add_section( 'parallax_frame_fixed_header_top', array(
	'panel'    => 'parallax_frame_theme_options',
	'title'    => esc_html__( 'Fixed Header Top Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[primary_menu_disable]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['primary_menu_disable'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[primary_menu_disable]', array(
	'label'    => esc_html__( 'Check to disable Primary Menu', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_fixed_header_top',
	'settings' => 'parallax_frame_theme_options[primary_menu_disable]',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[disable_primary_search]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_primary_search'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[disable_primary_search]', array(
	'label'    	=> esc_html__( 'Check to disable search in primary menu', 'parallax-frame-pro' ),
	'section'  	=> 'parallax_frame_fixed_header_top',
	'settings' 	=> 'parallax_frame_theme_options[disable_primary_search]',
	'type'     	=> 'checkbox',
) );
// Fixed Header Top Option End

// Font Family Options
$wp_customize->add_section( 'parallax_frame_font_family', array(
	'panel'  => 'parallax_frame_theme_options',
	'title'    	=> esc_html__( 'Font Family Options', 'parallax-frame-pro' ),
) );

$avaliable_fonts = parallax_frame_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
									'title_font' 		=> esc_html__( 'Site Title Font Family', 'parallax-frame-pro' ),
									'body_font' 		=> esc_html__( 'Default Font Family', 'parallax-frame-pro' ),
									'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'parallax-frame-pro' ),
									'content_title_font'=> esc_html__( 'Content Title Font Family', 'parallax-frame-pro' ),
									'content_font' 		=> esc_html__( 'Content Body Font Family', 'parallax-frame-pro' ),
									'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'parallax-frame-pro' )
								);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( 'parallax_frame_theme_options['. $key . ']', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults[ $key ],
		'sanitize_callback' => 'parallax_frame_sanitize_select',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options['. $key . ']', array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'parallax_frame_font_family',
		'settings' => 'parallax_frame_theme_options['. $key . ']',
		'type'	   => 'select',
	) );
}

$wp_customize->add_setting( 'parallax_frame_theme_options[reset_typography]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_typography'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[reset_typography]', array(
	'label'		=> esc_html__( 'Check to reset fonts', 'parallax-frame-pro' ),
	'section'	=> 'parallax_frame_font_family',
	'settings'	=> 'parallax_frame_theme_options[reset_typography]',
	'type'		=> 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'parallax_frame_footer_options', array(
	'description'	=> esc_html__( 'You can either add html or plain text', 'parallax-frame-pro'),
	'panel'  => 'parallax_frame_theme_options',
	'title'    		=> esc_html__( 'Footer Editor Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[footer_top_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_top_content'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_footer_code',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[footer_top_content]', array(
		'description' 	=> esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'parallax-frame-pro' ),
		'label'			=> esc_html__( 'Footer Top Content', 'parallax-frame-pro' ),
		'section'   	=> 'parallax_frame_footer_options',
        'settings'  	=> 'parallax_frame_theme_options[footer_top_content]',
		'type'			=> 'textarea',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[footer_bottom_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_bottom_content'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_footer_code',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[footer_bottom_content]', array(
		'label'		=> esc_html__( 'Footer Bottom Content', 'parallax-frame-pro' ),
		'section'   => 'parallax_frame_footer_options',
        'settings'  => 'parallax_frame_theme_options[footer_bottom_content]',
		'type'		=> 'textarea',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[reset_footer_content]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[reset_footer_content]', array(
	'label'		=> esc_html__( 'Check to reset Footer Content', 'parallax-frame-pro' ),
	'settings'	=> 'parallax_frame_theme_options[reset_footer_content]',
	'section'	=> 'parallax_frame_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

// Header Top Widget Area Options
$wp_customize->add_section( 'parallax_frame_header_top_options', array(
	'panel'			=> 'parallax_frame_theme_options',
	'title'   	 	=> esc_html__( 'Header Top Widget Area Options', 'parallax-frame-pro' ),
) );
$wp_customize->add_setting( 'parallax_frame_theme_options[enable_header_top]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['enable_header_top'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$display_options = parallax_frame_featured_slider_content_options();
$choices = array();
foreach ( $display_options as $display_option ) {
	$choices[$display_option['value']] = $display_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[enable_header_top]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Enable on', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_header_top_options',
	'settings' => 'parallax_frame_theme_options[enable_header_top]',
	'type'     => 'select',
) );

$header_top_desc = sprintf(
	wp_kses(
		__( 'Go <a href="%1$s">here</a> to add widgets to Header Top Widget Area', 'parallax-frame-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	"javascript:wp.customize.section( 'sidebar-widgets-header-top' ).focus();"
);

$wp_customize->add_setting( 'parallax_frame_theme_options[header_top_widget_note]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new parallax_frame_note_control( $wp_customize, 'parallax_frame_theme_options[header_top_widget_note]', array(
	'active_callback' => 'parallax_frame_is_header_top_active',
	'label'           => $header_top_desc,
	'section'         => 'parallax_frame_header_top_options',
	'settings'        => 'parallax_frame_theme_options[header_top_widget_note]',
	'type'            => 'description',
) ) );
// Header Top Widget Area Options End

//Homepage / Frontpage Options
$wp_customize->add_section( 'parallax_frame_homepage_options', array(
	'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'parallax-frame-pro' ),
	'panel'			=> 'parallax_frame_theme_options',
	'title'   	 	=> esc_html__( 'Homepage / Frontpage Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[front_page_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_category_list',
) );

$wp_customize->add_control( new parallax_frame_customize_dropdown_categories_control( $wp_customize, 'parallax_frame_theme_options[front_page_category]', array(
    'label'   	=> esc_html__( 'Select Categories', 'parallax-frame-pro' ),
    'name'	 	=> 'parallax_frame_theme_options[front_page_category]',
    'section'  	=> 'parallax_frame_homepage_options',
    'settings' 	=> 'parallax_frame_theme_options[front_page_category]',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End

// Layout Options
$wp_customize->add_section( 'parallax_frame_layout', array(
	'capability'=> 'edit_theme_options',
	'panel'		=> 'parallax_frame_theme_options',
	'title'		=> esc_html__( 'Layout Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[theme_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[theme_layout]', array(
	'choices'	=> parallax_frame_layouts(),
	'label'		=> esc_html__( 'Default Layout', 'parallax-frame-pro' ),
	'section'	=> 'parallax_frame_layout',
	'settings'   => 'parallax_frame_theme_options[theme_layout]',
	'type'		=> 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[content_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[content_layout]', array(
	'choices'   => parallax_frame_get_archive_content_layout(),
	'label'		=> esc_html__( 'Archive Content Layout', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_layout',
	'settings'  => 'parallax_frame_theme_options[content_layout]',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[single_post_image_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_post_image_layout'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );


$wp_customize->add_control( 'parallax_frame_theme_options[single_post_image_layout]', array(
		'label'		=> esc_html__( 'Single Page/Post Image Layout ', 'parallax-frame-pro' ),
		'section'   => 'parallax_frame_layout',
        'settings'  => 'parallax_frame_theme_options[single_post_image_layout]',
        'type'	  	=> 'select',
		'choices'  	=> parallax_frame_single_post_image_layout_options(),
) );
	// Layout Options End

// Pagination Options
$pagination_type	= $options['pagination_type'];

$nav_desc = sprintf(
	wp_kses(
		__( '<a target="_blank" href="%1$s">WP-PageNavi Plugin</a> is recommended for Numeric Option(But will work without it).<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'parallax-frame-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ),
	esc_url( 'https://wordpress.org/plugins/jetpack/' )
);

/**
* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
*/
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
	$nav_desc = sprintf(
		wp_kses(
			__( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'parallax-frame-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array()
				)
			)
		),
		esc_url( 'https://wordpress.org/plugins/jetpack/' )
	);
}
else {
	$nav_desc = '';
}
}

$wp_customize->add_section( 'parallax_frame_pagination_options', array(
	'description'	=> $nav_desc,
	'panel'  		=> 'parallax_frame_theme_options',
	'title'    		=> esc_html__( 'Pagination Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[pagination_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$pagination_types = parallax_frame_get_pagination_types();
$choices = array();
foreach ( $pagination_types as $pagination_type ) {
	$choices[$pagination_type['value']] = $pagination_type['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[pagination_type]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Pagination type', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_pagination_options',
	'settings' => 'parallax_frame_theme_options[pagination_type]',
	'type'	   => 'select',
) );
// Pagination Options End

//Promotion Headline Options
$wp_customize->add_section( 'parallax_frame_promotion_headline_options', array(
	'description'	=> esc_html__( 'To disable the fields, simply leave them empty.', 'parallax-frame-pro' ),
	'panel'			=> 'parallax_frame_theme_options',
	'title'   	 	=> esc_html__( 'Promotion Headline Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_headline_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_slider_content_options = parallax_frame_featured_slider_content_options();
$choices = array();
foreach ( $parallax_frame_featured_slider_content_options as $parallax_frame_featured_slider_content_option ) {
	$choices[$parallax_frame_featured_slider_content_option['value']] = $parallax_frame_featured_slider_content_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_headline_option]', array(
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Enable Promotion Headline on', 'parallax-frame-pro' ),
	'section'  	=> 'parallax_frame_promotion_headline_options',
	'settings' 	=> 'parallax_frame_theme_options[promotion_headline_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_headline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_headline]', array(
	'description'	=> esc_html__( 'Appropriate Words: 10', 'parallax-frame-pro' ),
	'label'    	=> esc_html__( 'Promotion Headline Text', 'parallax-frame-pro' ),
	'section' 	=> 'parallax_frame_promotion_headline_options',
	'settings'	=> 'parallax_frame_theme_options[promotion_headline]',
	'active_callback' => 'parallax_frame_is_promotional_headline_enabled',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_subheadline]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_subheadline]', array(
	'description'     => esc_html__( 'Appropriate Words: 15', 'parallax-frame-pro' ),
	'label'           => esc_html__( 'Promotion Subheadline Text', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_promotion_headline_options',
	'settings'        => 'parallax_frame_theme_options[promotion_subheadline]',
	'active_callback' => 'parallax_frame_is_promotional_headline_enabled',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_headline_button]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_headline_button]', array(
	'description'     => esc_html__( 'Appropriate Words: 3', 'parallax-frame-pro' ),
	'label'           => esc_html__( 'Promotion Headline Button Text ', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_promotion_headline_options',
	'settings'        => 'parallax_frame_theme_options[promotion_headline_button]',
	'type'            => 'text',
	'active_callback' => 'parallax_frame_is_promotional_headline_enabled',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_headline_url]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_headline_url]', array(
	'label'           => esc_html__( 'Promotion Headline Link', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_promotion_headline_options',
	'settings'        => 'parallax_frame_theme_options[promotion_headline_url]',
	'type'            => 'text',
	'active_callback' => 'parallax_frame_is_promotional_headline_enabled',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[promotion_headline_target]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[promotion_headline_target]', array(
	'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_promotion_headline_options',
	'settings'        => 'parallax_frame_theme_options[promotion_headline_target]',
	'type'            => 'checkbox',
	'active_callback' => 'parallax_frame_is_promotional_headline_enabled',
) );
// Promotion Headline Options End

// Scrollup
$wp_customize->add_section( 'parallax_frame_scrollup', array(
	'panel'    => 'parallax_frame_theme_options',
	'title'    => esc_html__( 'Scrollup Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[disable_scrollup]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[disable_scrollup]', array(
	'label'		=> esc_html__( 'Check to disable Scroll Up', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_scrollup',
    'settings'  => 'parallax_frame_theme_options[disable_scrollup]',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'parallax_frame_search_options', array(
	'description'=> esc_html__( 'Change default placeholder text in Search.', 'parallax-frame-pro'),
	'panel'  => 'parallax_frame_theme_options',
	'title'    => esc_html__( 'Search Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[search_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[search_text]', array(
	'label'		=> esc_html__( 'Default Display Text in Search', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_search_options',
    'settings'  => 'parallax_frame_theme_options[search_text]',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'parallax_frame_single_post_navigation', array(
	'panel'  => 'parallax_frame_theme_options',
	'title'    => esc_html__( 'Single Post Navigation', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[disable_single_post_navigation]', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[disable_single_post_navigation]', array(
	'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_single_post_navigation',
    'settings'  => 'parallax_frame_theme_options[disable_single_post_navigation]',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'parallax_frame_update_notifier', array(
	'title'    => esc_html__( 'Update Notifier', 'parallax-frame-pro' ),
	'panel'    => 'parallax_frame_theme_options',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[update_notifier]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[update_notifier]', array(
	'label'		=> esc_html__( 'Check to disable update notifications', 'parallax-frame-pro' ),
	'section'   => 'parallax_frame_update_notifier',
    'settings'  => 'parallax_frame_theme_options[update_notifier]',
	'type'		=> 'checkbox',
) );
// Update Notifier End